==> jena-3.7.0-source-release.zip: jena-3.7.0/jena-db/jena-dboe-base/src/test/java/org/apache/jena/dboe/base/file/TS_File.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.dboe.base.file;

import org.junit.runner.RunWith ;
import org.junit.runners.Suite ;

@RunWith(Suite.class)
@Suite.SuiteClasses( {
    TestMetaFile.class
    , TestSegmentedMemBuffer.class
    , TestChannelMem.class
    , TestChannelFile.class
    
    , TestBlockAccessMem.class
    , TestBlockAccessByteArray.class
    , TestBlockAccessDirect.class
    , TestBlockAccessMapped.class
    
    , TestBinaryDataMem.class
    , TestBinaryDataFileWriteBufferedMem.class
    , TestBinaryDataRAFInitial.class
    , TestBinaryDataRAF.class
    , TestBinaryDataFileWriteBufferedFile.class
    
    , TestProcessFileLock.class
})


public class TS_File
{
    public static String FILE = "target/test-read-append-file" ;
}

==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-db/jena-dboe-base/src/test/java/org/apache/jena/dboe/base/file/TS_File.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.dboe.base.file;

import org.junit.platform.suite.api.SelectClasses;
import org.junit.platform.suite.api.Suite;

@Suite
@SelectClasses({
    TestMetaFile.class
    , TestSegmentedMemBuffer.class
    , TestChannelMem.class
    , TestChannelFile.class

    , TestBlockAccessMem.class
    , TestBlockAccessByteArray.class
    , TestBlockAccessDirect.class
    , TestBlockAccessMapped.class

    , TestBinaryDataMem.class
    , TestBinaryDataFileWriteBufferedMem.class
    , TestBinaryDataRAFInitial.class
    , TestBinaryDataRAF.class
    , TestBinaryDataFileWriteBufferedFile.class

    , TestProcessFileLock.class
})

public class TS_File
{
    public static String FILE = "target/test-read-append-file";
}
